@@ -1,5 +1,5 @@
 package App::cpanminus;
-our $VERSION = "1.7045";
+our $VERSION = "1.7046";
 
 =encoding utf8
 
@@ -75,8 +75,7 @@ errors or certification warnings. This is due to your HTTP client
 to be updated.
 
 You're recommended to update the software or system if you can. If
-that is impossible or difficult, use the C<-k> option with curl or an
-alternative URL, C<https://git.io/cpanm>
+that is impossible or difficult, use the C<-k> option with curl.
 
 =head1 DEPENDENCIES
 
